@@ -11,63 +11,39 @@
 #' @param MEASURES Simulation output measures
 #' @param TIMEPOINT Timepoint being analysed
 #' @param TIMEPOINTSCALE Scale in which the timepoints are measures
+#' @param output_types Files types of graph to produce (pdf,png,bmp etc)
 #'
 #' @export
 efast_graph_Results <- function(RESULTS_FILE_PATH, PARAMETERS, si, sti,
                                 errors_si, errors_sti, MEASURES, TIMEPOINT,
-                                TIMEPOINTSCALE) {
-  if (requireNamespace("gplots", quietly = TRUE)) {
+                                TIMEPOINTSCALE, output_types=c("pdf")) {
 
-    colors <- c("black", "grey50")
 
-    for (MEASURE in seq(length(MEASURES))) {
+    for (MEASURE in 1:length(MEASURES)) {
 
-      if (is.null(TIMEPOINT)) {
-        GRAPHFILE <- paste(RESULTS_FILE_PATH, "/", MEASURES[MEASURE], ".pdf",
-                           sep = "")
-        GRAPHTITLE <- paste("Partitioning of Variance in Simulation Results
-                            Measure: ", MEASURES[MEASURE],
-                            sep = "")
-      } else {
-        GRAPHFILE <- paste(RESULTS_FILE_PATH, "/", MEASURES[MEASURE], "_",
-                           TIMEPOINT, ".pdf", sep = "")
-        GRAPHTITLE <- paste("Partitioning of Variance in Simulation Results
-                            Measure: ", MEASURES[MEASURE],
-                            ". Timepoint: ", TIMEPOINT, " ",
-                            TIMEPOINTSCALE, sep = "")
+      # October 2018 - rewritten to use ggplot2
+      si_results<-data.frame(rep("Si",length(PARAMETERS)),PARAMETERS,si[,,MEASURE], (as.numeric(si[,,MEASURE]) + as.numeric(errors_si[,MEASURE])),stringsAsFactors = FALSE)
+      colnames(si_results)<-c("Statistic","Parameter","Sensitivity","Error")
+      sti_results<-data.frame(rep("STi",length(PARAMETERS)),PARAMETERS,sti[,,MEASURE], (as.numeric(sti[,,MEASURE]) + as.numeric(errors_sti[,MEASURE])),stringsAsFactors = FALSE)
+      colnames(sti_results)<-c("Statistic","Parameter","Sensitivity","Error")
+
+      # Merge
+      graph_frame <- rbind(si_results,sti_results)
+
+      for(out in output_types)
+      {
+        ggplot2::ggplot(data=graph_frame, aes(x=graph_frame$Parameter, y=as.numeric(graph_frame$Sensitivity), fill=graph_frame$Statistic)) +
+          ggplot2::geom_bar(stat="identity", position=ggplot2::position_dodge()) + ggplot2::scale_fill_manual("", values = c("Si" = "black", "STi" = "darkgray")) +
+          theme(axis.text.x = element_text(angle = 65, hjust = 1, size=ggplot2::rel(0.75))) +
+          ggplot2::ggtitle(paste0("Partitioning of Variance in Simulation Results\n Measure: ",MEASURES[MEASURE])) + ggplot2::theme(plot.title = element_text(hjust = 0.5, size=ggplot2::rel(0.75))) +
+          ggplot2::geom_errorbar(aes(ymin=as.numeric(graph_frame$Sensitivity), ymax=as.numeric(graph_frame$Error)), width=.2, position=ggplot2::position_dodge(.9)) + ggplot2::ylim(0,1) +
+          ggplot2::xlab("Parameter")+ggplot2::ylab("Sensitivity")
+
+        ggplot2::ggsave(file.path(RESULTS_FILE_PATH,paste0(MEASURES[MEASURE],TIMEPOINT,".",out)))
       }
-
-      pdf(GRAPHFILE)
-      labelspacing <- seq(2, (length(PARAMETERS) * 3), 3)
-
-      # DATA TO GRAPH RETRIEVES THE PARAMETERS,
-      # si AND sti TO BE GRAPHED FROM THE MAIN RESULT SET
-      data_to_graph <- data.frame(cbind(si[, , MEASURE], sti[, , MEASURE]),
-                                check.names = FALSE)
-
-      # CONSTRUCT THE ERROR BAR
-      high_si <- data_to_graph[, 1] + errors_si[, MEASURE]
-      high_sti <- data_to_graph[, 2] + errors_sti[, MEASURE]
-      # COMBINE
-      errors_high <- cbind(high_si, high_sti)
-
-      colnames(data_to_graph) <- c("Si", "STi")
-      par(mar = c(9, 4, 4, 2) + 0.1)
-      gplots::barplot2(t(data_to_graph), names.arg = PARAMETERS, beside = TRUE,
-                       main = GRAPHTITLE,
-                       ylim = c(0, 1.0),
-                       ylab = "eFAST Sensitivity", col = colors, xaxt = "n",
-                       plot.ci = TRUE, ci.u = t(errors_high),
-                       ci.l = t(data_to_graph))
-
-      # TEXT SIZE CONTROLLED BY CEX.AXIS
-      axis(1, at = labelspacing, labels = PARAMETERS, las = 2, cex.axis = 0.6)
-      legend("topleft", title = NULL, c("Si", "STi"), fill = colors)
-
-      dev.off()
     }
     message(paste("Graphs Output to ", RESULTS_FILE_PATH, sep = ""))
-  }
+
 }
 
 #' Plot the Si value for all parameters for multiple simulation timepoints
